About Us
========

NetworkX was originally written by Aric Hagberg, Dan Schult, and Pieter Swart,
and has been developed with the help of many others. Thanks to everyone who has
improved NetworkX by contributing code, bug reports (and fixes), documentation,
and input on design, features, and the future of NetworkX.

.. include:: team.rst 

Contributors
------------

If you are a NetworkX contributor, please feel free to
open an `issue <https://github.com/networkx/networkx/issues/new>`_ or
submit a `pull request <https://github.com/networkx/networkx/compare/>`_
to add your name to the bottom of the list.

- Aric Hagberg, GitHub: `hagberg <https://github.com/hagberg>`_
- Dan Schult, GitHub: `dschult <https://github.com/dschult>`_
- Pieter Swart
- Katy Bold
- Hernan Rozenfeld
- Brendt Wohlberg
- Jim Bagrow
- Holly Johnsen
- Arnar Flatberg
- Chris Myers
- Joel Miller
- Keith Briggs
- Ignacio Rozada
- Phillipp Pagel
- Sverre Sundsdal
- Ross M. Richardson
- Eben Kenah
- Sasha Gutfriend
- Udi Weinsberg
- Matteo Dell'Amico
- Andrew Conway
- Raf Guns
- Salim Fadhley
- Fabrice Desclaux
- Arpad Horvath
- Minh Van Nguyen
- Willem Ligtenberg
- Loïc Séguin-C.
- Paul McGuire
- Jesus Cerquides
- Ben Edwards
- Jon Olav Vik
- Hugh Brown
- Ben Reilly
- Leo Lopes
- Jordi Torrents, GitHub: `jtorrents <https://github.com/jtorrents>`_
- Dheeraj M R
- Franck Kalala
- Simon Knight
- Conrad Lee
- Sérgio Nery Simões
- Robert King
- Nick Mancuso
- Brian Cloteaux
- Alejandro Weinstein
- Dustin Smith
- Mathieu Larose
- Romain Fontugne
- Vincent Gauthier
- chebee7i, GitHub: `chebee7i <https://github.com/chebee7i>`_
- Jeffrey Finkelstein
- Jean-Gabriel Young, Github: `jg-you <https://github.com/jgyou>`_
- Andrey Paramonov, http://aparamon.msk.ru
- Mridul Seth, GitHub: `MridulS <https://github.com/MridulS>`_
- Thodoris Sotiropoulos, GitHub: `theosotr <https://github.com/theosotr>`_
- Konstantinos Karakatsanis, GitHub: `k-karakatsanis <https://github.com/k-karakatsanis>`_
- Ryan Nelson, GitHub: `rnelsonchem <https://github.com/rnelsonchem>`_
- Niels van Adrichem, GitHub: `NvanAdrichem <https://github.com/NvanAdrichem>`_
- Michael E. Rose, GitHub: `Michael-E-Rose <https://github.com/Michael-E-Rose>`_
- Jarrod Millman, GitHub: `jarrodmillman <https://github.com/jarrodmillman>`_
- Andre Weltsch
- Lewis Robbins
- Mads Jensen, Github: `atombrella <https://github.com/atombrella>`_
- Edward L. Platt, `elplatt <https://elplatt.com>`_
- James Owen, Github: `leamingrad <https://github.com/leamingrad>`_
- Robert Gmyr, Github: `gmyr <https://github.com/gmyr>`_
- Mike Trenfield
- Jon Crall, Github: `Erotemic <https://github.com/Erotemic>`_
- Issa Moradnejad, Github `<https://github.com/Moradnejad>`_, LinkedIn `<https://linkedin.com/in/moradnejad/>`_
- Brian Kiefer, Github: `bkief <https://github.com/bkief>`_
- Julien Klaus
- Peter C. Kroon, Github: `pckroon <https://github.com/pckroon>`_
- Weisheng Si, Github: `ws4u <https://github.com/ws4u>`_
- Haakon H. Rød, Gitlab: `haakonhr <https://gitlab.com/haakonhr>`_, `<https://haakonhr.gitlab.io>`_
- Efraim Rodrigues, GitHub `<https://github.com/efraimrodrigues>`_, LinkedIn `<https://linkedin.com/in/efraim-rodrigues/>`_
- Erwan Le Merrer
- Søren Fuglede Jørgensen, GitHub: `fuglede <https://github.com/fuglede>`_
- Salim BELHADDAD, LinkedIn `<https://www.linkedin.com/in/salymdotme/>`_
- Jangwon Yie, GitHub `<https://github.com/jangwon-yie>`_, LinkedIn `<https://www.linkedin.com/in/jangwon-yie-a7960065/>`_
- ysitu
- Tomas Gavenciak
- Luca Baldesi
- Yuto Yamaguchi
- James Clough
- Minas Gjoka
- Drew Conway
- Alex Levenson
- Haochen Wu
- Erwan  Le Merrer
- Alex Roper
- P C Kroon
- Christopher Ellison
- D. Eppstein
- Federico Rosato
- Aitor Almeida
- Ferran Parés
- Christian Olsson
- Fredrik Erlandsson
- Nanda H Krishna
- Nicholas Mancuso
- Fred Morstatter
- Ollie Glass
- Rodrigo Dorantes-Gilardi
- Pranay Kanwar
- Balint Tillman
- Diederik van Liere
- Ferdinando Papale
- Miguel Sozinho Ramalho
- Brandon Liu
- Nima Mohammadi
- Jason Grout
- Jan Aagaard Meier
- Henrik Haugbølle
- Piotr Brodka
- Sasha Gutfraind
- Alessandro Luongo
- Huston Hedinger
- Oleguer Sagarra
- Kazimierz Wojciechowski, GitHub `<https://github.com/kazimierz-256>`_, LinkedIn `<https://linkedin.com/in/wojciechowski-kazimierz/>`_
- Gaetano Pietro Paolo Carpinato, Github `<https://github.com/Carghaez>`_, LinkedIn `<https://linkedin.com/in/gaetanocarpinato/>`_
- Arun Nampally, GitHub `<https://github.com/arunwise>`_, LinkedIn `<https://www.linkedin.com/in/arun-nampally-b57845b7/>`_
- Ryan Duve
- Shashi Prakash Tripathi, Github `<https://github.com/itsshavar>`_,LinkedIn `<https://www.linkedin.com/in/itsshashitripathi/>`_
- Danny Niquette
- James Trimble, Github: `jamestrimble <https://github.com/jamestrimble>`_
- Matthias Bruhns, Github `<https://github.com/mbruhns>`_ 
- Philip Boalch
- Matt Schwennesen, Github: `mjschwenne <https://github.com/mjschwenne>`_

A supplementary (but still incomplete) list of contributors is given by the
list of names that have commits in ``networkx``'s
`git <http://git-scm.com>`_ repository. This can be obtained via::

    git log --raw | grep "^Author: " | sort | uniq

A historical, partial listing of contributors and their contributions to some
of the earlier versions of NetworkX can be found
`here <https://github.com/networkx/networkx/blob/886e790437bcf30e9f58368829d483efef7a2acc/doc/source/reference/credits_old.rst>`_.


Support
-------

NetworkX acknowledges support from the following research groups:

- `Center for Nonlinear Studies <http://cnls.lanl.gov>`_, Los Alamos National
  Laboratory, PI: Aric Hagberg

- `Open Source Programs Office <https://developers.google.com/open-source/>`_,
  Google

- `Complexity Sciences Center <http://csc.ucdavis.edu/>`_, Department of
  Physics, University of California-Davis, PI: James P. Crutchfield

- `Center for Complexity and Collective Computation <http://c4.discovery.wisc.edu>`_,
  Wisconsin Institute for Discovery, University of Wisconsin-Madison,
  PIs: Jessica C. Flack and David C. Krakauer

NetworkX acknowledges the following financial support:

- Google Summer of Code via Python Software Foundation

- U.S. Army Research Office grant W911NF-12-1-0288

- DARPA Physical Intelligence Subcontract No. 9060-000709

- NSF Grant No. PHY-0748828

- John Templeton Foundation through a grant to the Santa Fe Institute to
  study complexity

- U.S. Army Research Laboratory and the U.S. Army Research Office under
  contract number W911NF-13-1-0340
